helga-twitter
=============

twitter from irc, like it was meant to be



TODO
----------------

2. delete tweets
3. DM from channel
4. authentication + authorization for subsets of users to have different abilities
